// FILENAME: RACE_GT_Phoenix.cs
//
// TRACK CREATOR: Gen. Raven [M.I.B.]
//
// Original NASHERC Racing script created by Com. Sentinal [M.I.B.].
//------------------------------------------------------------------------------ 

exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");
exec("NASHERCstdLib.cs");

//Fill out these global variables before you make a custom race track!!!
//------------------------------------------------------------------------------
$missionName = "Phoenix International Raceway"; //Track Name

//Different series allow different vehicles, weapons, components,
//mass limits, and tech mixing options.
//Keep the series name & abbreviation the same if you don't want 
//to change the current restrictions.
//If you want to change the series, merely change the series name
//and abbreviation to one of the following:
//
//1.  "Winston Cup" & "WC"        //Allows Emans, Goads, Talons, & Seekers
//2.  "Busch" & "BSH"             //Allows Knight's Apocs (turbines)
//3.  "Seeker" & "SK"             //Allows Seekers (turbines & rockets)
//4.  "Craftsman Tank" & "TK"     //Allows Bolos, Preds, & Disrupters (turbines)
//5.  "Goad/Talon" & "GT"         //Allows Goads & Talons
//
//The script will automatically recognize the series name you chose
//and will use its restriction settings in the game.

$Series = "Goad/Talon";  //Series name
$SeriesAbbreviation = "GT";  //Series Abbreviation

//The mission creator is used in the download message and in other areas of the script.
//The download message is used if you have any custom message you would 
//like to add when a player joins the game.

$missionCreator = "Gen. Raven [M.I.B.]";
$downloadMessage = "You can download this & other missions made by " @ $missionCreator @ " in the \"MIB Map Packs\" on the MIB Website at www.starsiegemeninblack.cjb.net.";

//These are the coordinates where you respawn if you die during the race.
//You always start at the last checkpoint you crossed.
//Be sure to fill these out if you're making a custom track.
//------------------------------------------------------------------------------

//Checkpoint #1 coordinates
$checkpoint1x = 0;            //Checkpoint #1 x coordinate
$checkpoint1y = 0;            //Checkpoint #1 y coordinate
$checkpoint1z = 0;            //Checkpoint #1 z coordinate
$checkpoint1rot = 0;          //Checkpoint #1 rotation coordinate (degrees)

//Checkpoint #2 coordinates
$checkpoint2x = 0;            //Checkpoint #2 x coordinate
$checkpoint2y = 0;            //Checkpoint #2 y coordinate
$checkpoint2z = 0;            //Checkpoint #2 z coordinate
$checkpoint2rot = 0;          //Checkpoint #2 rotation coordinate (degrees)

//Making a custom NASHERC RaceTrack
//------------------------------------------------------------------------------
//First, make sure you filled out all of the global variables above.
//
//The following is instructions on how to make a custom race track in the
//Starsiege Mission Editor:
//
//#1 - First you must have a track built that is fully enclosed and has
//a pit road. Make sure that the pit road is placed so that it doesn't
//become a short-cut. I recommend that your pit road contain 2-3 zen pads.
//Make sure that your Zen pad triggers have the script class "ZenAll".
//
//#2 - Next, you must place certain triggers around the track.
//VERY IMPORTANT: Make sure that all of the triggers in the map have
//"Is Sphere" disabled. IF they DO NOT have it disabled, then errors in 
//lap scoring WILL occur. The following is a list of the triggers that 
//you need and where they must be placed in order to work correctly. 
//The name of each trigger refers to the script class that must be used:
//
//    A. - The "finishline" trigger should be placed at the start/finish line.
//    B. - The "checkpoint1" trigger should be placed 1/3 of the way around
//         the track.
//    C. - The "checkpoint2" trigger should be placed 2/3 of the way around
//         the track.
//    D. - The "pitroad" trigger should be placed at the beginning of pit road.
//    E. - The "exitpitroad" trigger should be placed at the end of pit road.
//
//#3 - Next, you must make a folder in Missiongroup called "StartGates".
//Inside that folder, you must put in 2 bridges. Name one of them "StartGate"
//and name the other one "BackWall". Make sure that their script class is
//named this as well as their object names. Rotate the bridges so that they
//become walls. Place the one called "StartGate" right before the
//"finishline" trigger. Make sure that you allow enough space between the
//"startGate" wall and the "finishline" trigger. Then, lower the "StartGate"
//wall into the ground so that a herc can see over it. Next, place the
//"BackWall" wall about 100-150 meters behind the "StartGate" wall. Leave
//the "BackWall" wall high, so that nothing can see over it.
//
//#4 - Next, place 10 deathmatch drop points between the "StartGate" & the
//"Backwall".
//
//#5 - Finally, get the coordinates for the checkpoint triggers & write them
//in their proper location at the top of the script.
//
//Now, your custom NASHERC RaceTrack should work perfectly IF you followed
//the directions above for making the track & filled in the global variables
//at the top of the script.
//------------------------------------------------------------------------------


//If you want to customize your map's script in any way, modify the
//provided functions below.
//------------------------------------------------------------------------------

function NashercOnMissionStart()
{
   desertSounds();
   windSounds();

   $flag1 = getObjectId("MissionGroup\\flag1");
   $flag2 = getObjectId("MissionGroup\\flag2");
   $flag3 = getObjectId("MissionGroup\\flag3");
   $flag4 = getObjectId("MissionGroup\\flag4");
   $flag5 = getObjectId("MissionGroup\\flag5");
   $nav1 = getObjectId("MissionGroup\\nav1");
   $nav2 = getObjectId("MissionGroup\\nav2");
   $nav3 = getObjectId("MissionGroup\\nav3");
   $nav4 = getObjectId("MissionGroup\\nav4");
   $nav5 = getObjectId("MissionGroup\\nav5");
   $nav6 = getObjectId("MissionGroup\\nav6");
   $trig1 = getObjectId("MissionGroup\\checkpoint1");
   $trig2 = getObjectId("MissionGroup\\checkpoint2");
   $trig3 = getObjectId("MissionGroup\\checkpoint3");
   $trig4 = getObjectId("MissionGroup\\checkpoint4");
   $trig5 = getObjectId("MissionGroup\\checkpoint5");   
   $m1L = getObjectId("MissionGroup\\markers\\1L");
   $m1C = getObjectId("MissionGroup\\markers\\1C");
   $m1R = getObjectId("MissionGroup\\markers\\1L");
   $m2L1 = getObjectId("MissionGroup\\markers\\2L1");
   $m2L2 = getObjectId("MissionGroup\\markers\\2L2");
   $m2L3 = getObjectId("MissionGroup\\markers\\2L3");
   $m2R1 = getObjectId("MissionGroup\\markers\\2R1");
   $m2R2 = getObjectId("MissionGroup\\markers\\2R2");
   $m2R3 = getObjectId("MissionGroup\\markers\\2R3");
   $m3L1 = getObjectId("MissionGroup\\markers\\3L1");
   $m3L2 = getObjectId("MissionGroup\\markers\\3L2");
   $m3L3 = getObjectId("MissionGroup\\markers\\3L3");
   $m3R1 = getObjectId("MissionGroup\\markers\\3R1");
   $m3R2 = getObjectId("MissionGroup\\markers\\3R2");
   $m3R3 = getObjectId("MissionGroup\\markers\\3R3");
   $m4R1 = getObjectId("MissionGroup\\markers\\4R1");
   $m4R2 = getObjectId("MissionGroup\\markers\\4R2");
   $m4R3 = getObjectId("MissionGroup\\markers\\4R3");
   $m4R4 = getObjectId("MissionGroup\\markers\\4R4");
   $m4L1 = getObjectId("MissionGroup\\markers\\4L1");
   $m4L2 = getObjectId("MissionGroup\\markers\\4L2");
   $m4L3 = getObjectId("MissionGroup\\markers\\4L3");
   $m4L4 = getObjectId("MissionGroup\\markers\\4L4");
   $m5C1 = getObjectId("MissionGroup\\markers\\5C1");
   $m5C2 = getObjectId("MissionGroup\\markers\\5C2");
   $m5C3 = getObjectId("MissionGroup\\markers\\5C3");
   $m5C4 = getObjectId("MissionGroup\\markers\\5C4");
   schedule("makeTrack();",2);
}

function NashercOnMissionLoad()
{
   cdAudioCycle("CloudBurst", "Terror", "NewTech", "Mechsoul");
   // Extra junk
   %count = playerManager::getPlayerCount();
   for(%i = 0; %i < %count; %i++)
   {
      %player = playerManager::getPlayerNum(%i);
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
   }
}

function NashercPlayerOnAdd(%player)
{
   %player.check3 = 0;
   %player.check4 = 0;
   %player.check5 = 0;
}

function NashercPlayerOnRemove(%player)
{
   //Blank function
}

function NashercVehicleOnAdd(%vehicleId)
{
   //Blank function
}

function NashercVehicleOnAttacked(%attacked, %attacker)
{
   //Blank function
}

function NashercVehicleOnDestroyed(%destroyed, %destroyer)
{
   //Blank function
}


//Extra optional functions (for advanced scripters)
//These functions are run whenever certain NASHERC race-related events occur.
//------------------------------------------------------------------------------

function NashercOnStartCountdown()
{
   //Blank function
}

function NashercOnStartRace()
{
   //Blank function
}

function NashercOnFinishRace()
{
   //Blank function
}

function NashercCheckpoint1OnArrived(%trigger, %vehicleId)
{
   //Blank function
}

function NashercCheckpoint2OnArrived(%trigger, %vehicleId)
{
   //Blank function
}

function NashercFinishLineOnArrived(%trigger, %vehicleId)
{
   //Blank function
}

function NashercPitRoadOnEnter(%trigger, %vehicleId)
{
   //Blank function
}

function NashercPitRoadOnLeave(%trigger, %vehicleId)
{
   //Blank function
}


//------------------------------------------------------------------------------
//Extra Scripting for this track only
//This is not needed to make a custom NASHERC RaceTrack
//------------------------------------------------------------------------------

function vehicle::onAdd(%vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   %player.vehtype = getVehicleName(%vehicleId);
   %player.delay = false;
   if($countdown == false)
   {
      if(playerManager::getPlayerCount() == 1)
      {
         messageBox(%player, "At least 2 players must be in the server before the countdown to the race will begin. Please wait until another player joins the server to race.");
      }
      else if(playerManager::getPlayerCount() >= 2)
      {
         $countdown = true;
         $countdownStartTime = getCurrentTime();
         countdown();
         say("Everybody", 10, "3 minutes until the race begins...");
         %txt1 = "\"2 minutes until the race begins...\"";
         %txt2 = "\"1 minute until the race begins...\"";
         %txt3 = "\"30 seconds until the race begins...\"";
         %txt4 = "\"15 seconds until the race begins...\"";
         %txt5 = "\"<jc>10\"";
         %txt6 = "\"<jc>9\"";
         %txt7 = "\"<jc>8\"";
         %txt8 = "\"<jc>7\"";
         %txt9 = "\"<jc>6\"";
         %txt10 = "\"<jc>5\"";
         %txt11 = "\"<jc>4\"";
         %txt12 = "\"<jc>3\"";
         %txt13 = "\"<jc>2\"";
         %txt14 = "\"<jc>1\"";
         schedule("say(0, 10, " @ %txt1 @ ");", 60);
         schedule("say(0, 11, " @ %txt2 @ ");", 120);
         schedule("$ThirtySecondsLeft = true;", 150);
         schedule("say(0, 12, " @ %txt3 @ ");", 150);
         schedule("say(0, 13, " @ %txt4 @ ");", 165);
         schedule("say(0, 14, " @ %txt5 @ ");", 170);
         schedule("say(0, 15, " @ %txt6 @ ");", 171);
         schedule("say(0, 16, " @ %txt7 @ ");", 172);
         schedule("say(0, 17, " @ %txt8 @ ");", 173);
         schedule("say(0, 18, " @ %txt9 @ ");", 174);
         schedule("say(0, 19, " @ %txt10 @ ");", 175);
         schedule("say(0, 20, " @ %txt11 @ ");", 176);
         schedule("say(0, 21, " @ %txt12 @ ");", 177);
         schedule("say(0, 22, " @ %txt13 @ ");", 178);
         schedule("say(0, 23, " @ %txt14 @ ");", 179);
         schedule("startrace();", 180);
      }
   }

   if(($racing == false)&&($countdown == true))
   {
      %player.late = false;
      $timeLeft = 180 - (getCurrentTime() -  $countdownStartTime);
      if($ThirtySecondsLeft == false)
      {
         setHudTimer($timeLeft, -1, "Race begins in:", 1, %player);
         messagebox(%player, "The race has not started yet, please wait until the timer reaches zero to race.");
      }
      else if($ThirtySecondsLeft == true)
      {
         setHudTimer($timeLeft, -1, "Race begins in:", 1, %player);
         say(%player, %player, "Get ready to race!");
      }
   }
   else if($racing == true)
   {
      if(%player.late == true)
      {
         healObject(%vehicleId, -50000); 
         messageBox(%player, "You cannot enter the game while a race is in progress. Please wait until the next race to join.");
      }
      else if(%player.late == false)
      {
         if((%player.check1 == 1)&&(%player.check2 == 0)&&(%player.check3 == 0)&&(%player.check4 == 0)&&(%player.check5 == 0))
         {
            setPosition(%vehicleId, $checkpoint1x, $checkpoint1y, $checkpoint1z, $checkpoint1rot);
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");
         }
         else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 0)&&(%player.check4 == 0)&&(%player.check5 == 0))
         {
            setPosition(%vehicleId, $checkpoint2x, $checkpoint2y, $checkpoint2z, $checkpoint2rot);
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");  
         }
         else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 0)&&(%player.check5 == 0))
         {
            setPosition(%vehicleId, $checkpoint3x, $checkpoint3y, $checkpoint3z, $checkpoint3rot);
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");  
         }
         else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 0))
         {
            setPosition(%vehicleId, $checkpoint4x, $checkpoint4y, $checkpoint4z, $checkpoint4rot);
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");  
         }
         else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1))
         {
            setPosition(%vehicleId, $checkpoint5x, $checkpoint5y, $checkpoint5z, $checkpoint5rot);
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");  
         }
         else
         {
            say(%player, %player, "Hurry up " @ getName(%player) @ "! You can still catch up with the pack!");
         }
      }
   }
   
   NashercVehicleOnAdd(%vehicleId);
}

function checkpoint1::trigger::OnEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   %player.check1 = 1;
   say(%player, %player, "<f5>Checkpoint 1! Proceed to nav 002.");
   setNavMarker($nav2, true, %vehicleId); 
   
   NashercCheckpoint1OnArrived();
} 

function checkpoint2::trigger::OnEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   if(%player.check1 == 1)
   {
      %player.check2 = 1;
      say(%player, %player, "<f5>Checkpoint 2! Proceed to nav 003.");
      setNavMarker($nav3, true, %vehicleId); 
   }

   NashercCheckpoint2OnArrived();
} 

function checkpoint3::trigger::OnEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   if((%player.check1 == 1)&&(%player.check2 == 1))
   {
      %player.check3 = 1;
      say(%player, %player, "<f5>Checkpoint 3! Proceed to nav 004.");
      setNavMarker($nav4, true, %vehicleId); 
   }
} 

function checkpoint4::trigger::OnEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1))
   {
      %player.check4 = 1;
      say(%player, %player, "<f5>Checkpoint 4! Proceed to nav 005.");
      setNavMarker($nav5, true, %vehicleId); 
   }
} 

function checkpoint5::trigger::OnEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1))
   {
      %player.check5 = 1;
      say(%player, %player, "<f5>Checkpoint 5! Proceed to nav 006.");
      setNavMarker($nav6, true, %vehicleId); 
   }
} 

function finishline::trigger::OnEnter(%trigger, %vehicleId)
{  
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   setNavMarker($nav1, true, %vehicleId); 
   if((%player.check1 == 0)&&(%player.check2 == 0)&&(%player.check3 == 0)&&(%player.check4 == 0)&&(%player.check5 == 0)&&(%player.points == 0))
   {
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.time1 = getCurrentTime();
      say(%player, %player, "<f5>LAP 1! Proceed to nav 001.");
      if($leader1==true)
      {
         $leader1 = false;
         say("Everybody", 1, getName(%player) @ " takes the lead on lap 1!");
      }
   }
   else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1)&&(%player.points == 0))
   {
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.laptime1 = timeDifference(getCurrentTime(), %player.time1);
      %player.time2 = getCurrentTime();
      %player.points++;
      say(%player, %player, "LAPTIME: " @ %player.laptime1);
      say(%player, %player, "LAP 2! Proceed to nav 001.");
      %player.fastlap = %player.laptime1;
      %player.fastestlap = "Lap 1 - " @ %player.laptime1;
      if($leader2 == true)
      {  
         $leader2 = false;
         %player.lapsled++;
         say("Everybody", 1, "The leader, " @ getName(%player) @ ", is currently on lap 2.");
         if(%player.lapsled==1)
         {
            %player.leadalap = 4;
         }
      }
   }   
   else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1)&&(%player.points == 1))
   {
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.laptime2 = timeDifference(getCurrentTime(), %player.time2);
      %player.time3 = getCurrentTime();
      %player.points++;
      say(%player, %player, "LAPTIME: " @ %player.laptime2);
      say(%player, %player, "LAP 3! Proceed to nav 001.");
      if($leader3 == true)
      {  
         $leader3 = false;
         %player.lapsled++;
         say("Everybody", 1, "The leader, " @ getName(%player) @ ", is currently on lap 3.");
         if(%player.lapsled == 1)
         {
            %player.leadalap = 4;
         }
      }
      if(%player.laptime2 < %player.fastlap)
      {
         %player.fastlap = %player.laptime2;
         %player.fastestlap = "Lap 2 - " @ %player.laptime2;
      }
   }   
   else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1)&&(%player.points == 2))
   {
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.laptime3 = timeDifference(getCurrentTime(), %player.time3);
      %player.time4 = getCurrentTime();
      %player.points++;
      say(%player, %player, "LAPTIME: " @ %player.laptime3);
      say(%player, %player, "LAP 4! Proceed to nav 001.");
      if($leader4 == true)
      {  
         $leader4 = false;
         %player.lapsled++;
         say("Everybody", 1, "The leader, " @ getName(%player) @ ", is currently on lap 4.");
         if(%player.lapsled == 1)
         {
            %player.leadalap = 4;
         }
      }
      if(%player.laptime3 < %player.fastlap)
      {
         %player.fastlap = %player.laptime3;
         %player.fastestlap = "Lap 3 - " @ %player.laptime3;
      }
   }
   else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1)&&(%player.points == 3))
   {
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.laptime4 = timeDifference(getCurrentTime(), %player.time4);
      %player.time5 = getCurrentTime();
      %player.points++;
      say(%player, %player, "LAPTIME: " @ %player.laptime4);
      say(%player, %player, "FINAL LAP! Proceed to nav 001.");
      if($leader5 == true)
      {  
         $leader5 = false;
         %player.lapsled++;
         say("Everybody", 1, "The leader, " @ getName(%player) @ ", is on the final lap!");
         if(%player.lapsled == 1)
         {
            %player.leadalap = 4;
         }
      }
      if(%player.laptime4 < %player.fastlap)
      {
         %player.fastlap = %player.laptime4;
         %player.fastestlap = "Lap 4 - " @ %player.laptime4;
      }
   }
   else if((%player.check1 == 1)&&(%player.check2 == 1)&&(%player.check3 == 1)&&(%player.check4 == 1)&&(%player.check5 == 1)&&(%player.points == 4)&&($winner == false))
   {
      $winner = true;
      %player.winnings = 10;
      %player.check1 = 0;
      %player.check2 = 0;
      %player.check3 = 0;
      %player.check4 = 0;
      %player.check5 = 0;
      %player.laptime5 = timeDifference(getCurrentTime(), %player.time5);
      %player.points++;
      %player.lapsled++;
      if(%player.lapsled == 1)
      {
         %player.leadalap = 4;
      }
      say(%player, %player, "LAPTIME: " @ %player.laptime5);
      if(%player.laptime5 < %player.fastlap)
      {
         %player.fastlap = %player.laptime5;
         %player.fastestlap = "Lap 5 - " @ %player.laptime5;
      }
      say("Everybody", 1, getName(%player) @ " has won the race!");
      setFlybyCamera(%vehicleId, -15, 0, 15);
      messagebox("Everybody", getName(%player) @ " has won the race!");
      %count = playerManager::getPlayerCount();
      for(%i = 0; %i < %count; %i++)
      {
         %playerNumber = playerManager::getPlayerNum(%i);
         %playerNumber.temp = getStandings(%playerNumber);
      }
      schedule("missionEndConditionMet();",10);

      NashercOnFinishRace();
   }

   NashercFinishLineOnArrived();
} 

function makeTrack()
{
   %random = randomInt(1, 2);
   if(%random == 1)
   {
      %dir = "L"; 
      %random = randomInt(1, 2);
      if(%random == 1)
      {
         %m1 = $m1C;
         %text1 = "1C";
      } 
      else if(%random == 2)
      {
         %m1 = $m1L;
         %text1 = "1L";
      } 
   }
   else if(%random == 2)
   {
      %dir = "R"; 
      %random = randomInt(1, 2);
      if(%random == 1)
      {
         %m1 = $m1C;
         %text1 = "1C";
      } 
      else if(%random == 2)
      {
         %m1 = $m1R;
         %text1 = "1R";
      } 
   }
   %num2 = randomInt(1, 3);
   %m2 = $m2[%dir@""@%num2];
   %num3 = randomInt(1, 3);
   %m3 = $m3[%dir@""@%num3];
   %num4 = randomInt(1, 4);
   %m4 = $m4[%dir@""@%num4];
   %num5 = randomInt(1, 4);
   %m5 = $m5C[%num5];
   %text2 = "2"@%dir@""@%num2;
   %text3 = "3"@%dir@""@%num3;
   %text4 = "4"@%dir@""@%num4;
   %text5 = "5C"@%num5;
   echo("Checkpoint 1 -  "@%text1);
   echo("Checkpoint 2 -  "@%text2);
   echo("Checkpoint 3 -  "@%text3);
   echo("Checkpoint 4 -  "@%text4);
   echo("Checkpoint 5 -  "@%text5);
   $checkpoint1x = getPosition(%m1, x);
   $checkpoint1y = getPosition(%m1, y);
   $checkpoint1z = getPosition(%m1, z) + 5;
   $checkpoint2x = getPosition(%m2, x);
   $checkpoint2y = getPosition(%m2, y);
   $checkpoint2z = getPosition(%m2, z) + 5;
   $checkpoint3x = getPosition(%m3, x);
   $checkpoint3y = getPosition(%m3, y);
   $checkpoint3z = getPosition(%m3, z) + 5;
   $checkpoint4x = getPosition(%m4, x);
   $checkpoint4y = getPosition(%m4, y);
   $checkpoint4z = getPosition(%m4, z) + 5;
   $checkpoint5x = getPosition(%m5, x);
   $checkpoint5y = getPosition(%m5, y);
   $checkpoint5z = getPosition(%m5, z) + 5;
   $checkpoint1rot = getAngle($checkpoint1x, $checkpoint1y, $checkpoint2x, $checkpoint2y)-90;
   $checkpoint2rot = getAngle($checkpoint2x, $checkpoint2y, $checkpoint3x, $checkpoint3y)-90;
   $checkpoint3rot = getAngle($checkpoint3x, $checkpoint3y, $checkpoint4x, $checkpoint4y)-90;
   $checkpoint4rot = getAngle($checkpoint4x, $checkpoint4y, $checkpoint5x, $checkpoint5y)-90;
   $checkpoint5rot = getAngle($checkpoint5x, $checkpoint5y, getPosition($nav6, x), getPosition($nav6, y))-90;
   setPosition($nav1, $checkpoint1x, $checkpoint1y, getTerrainHeight($checkpoint1x, $checkpoint1y));
   setPosition($nav2, $checkpoint2x, $checkpoint2y, getTerrainHeight($checkpoint2x, $checkpoint2y));
   setPosition($nav3, $checkpoint3x, $checkpoint3y, getTerrainHeight($checkpoint3x, $checkpoint3y));
   setPosition($nav4, $checkpoint4x, $checkpoint4y, getTerrainHeight($checkpoint4x, $checkpoint4y));
   setPosition($nav5, $checkpoint5x, $checkpoint5y, getTerrainHeight($checkpoint5x, $checkpoint5y));
   setPosition($flag1, $checkpoint1x, $checkpoint1y, getTerrainHeight($checkpoint1x, $checkpoint1y));
   setPosition($flag2, $checkpoint2x, $checkpoint2y, getTerrainHeight($checkpoint2x, $checkpoint2y));
   setPosition($flag3, $checkpoint3x, $checkpoint3y, getTerrainHeight($checkpoint3x, $checkpoint3y));
   setPosition($flag4, $checkpoint4x, $checkpoint4y, getTerrainHeight($checkpoint4x, $checkpoint4y));
   setPosition($flag5, $checkpoint5x, $checkpoint5y, getTerrainHeight($checkpoint5x, $checkpoint5y));
   setPosition($trig1, $checkpoint1x, $checkpoint1y, getTerrainHeight($checkpoint1x, $checkpoint1y));
   setPosition($trig2, $checkpoint2x, $checkpoint2y, getTerrainHeight($checkpoint2x, $checkpoint2y));
   setPosition($trig3, $checkpoint3x, $checkpoint3y, getTerrainHeight($checkpoint3x, $checkpoint3y));
   setPosition($trig4, $checkpoint4x, $checkpoint4y, getTerrainHeight($checkpoint4x, $checkpoint4y));
   setPosition($trig5, $checkpoint5x, $checkpoint5y, getTerrainHeight($checkpoint5x, $checkpoint5y));
}


// Trigonometric Stuff for this track only
// (not required to make a race track)
//------------------------------------------------------------------------------ 

function getAngle(%x1, %y1, %x2, %y2)
{
   //Angle is defined from point A (x1, y1) to point B (x2, y2)
   //Point A (x1, y1) is the base point (center of the protractor)
   //Be sure to enter the coordinates for the base point first (x1, y1)

   %deltaX = %x2 - %x1;
   %deltaY = %y2 - %y1;
   %angle = getVector(%deltaX, %deltaY);
   return %angle;
}

function getVector(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);   
   if((%tan >= -0.008728)&&(%tan < 0.008728))
   {
      if(%deltaX > 0)
      {
         %angle = 0;
      }
      else if(%deltaX < 0)
      {
         %angle = 180;
      }
      return %angle;
   }
   else if((%tan >= 0.008728)&&(%tan < 0.026188))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 1;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 181;
      }
      return %angle;
   }
   else if((%tan >= 0.026188)&&(%tan < 0.043664))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 2;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 182;
      }
      return %angle;
   }
   else if((%tan >= 0.043664)&&(%tan < 0.061167))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 3;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 183;
      }
      return %angle;
   }
   else if((%tan >= 0.061167)&&(%tan < 0.078708))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 4;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 184;
      }
      return %angle;
   }
   else if((%tan >= 0.078708)&&(%tan < 0.096296))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 5;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 185;
      }
      return %angle;
   }
   else if((%tan >= 0.096296)&&(%tan < 0.113944))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 6;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 186;
      }
      return %angle;
   }
   else if((%tan >= 0.113944)&&(%tan < 0.131663))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 7;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 187;
      }
      return %angle;
   }
   else if((%tan >= 0.131663)&&(%tan < 0.149463))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 8;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 188;
      }
      return %angle;
   }
   else if((%tan >= 0.149463)&&(%tan < 0.167356))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 9;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 189;
      }
      return %angle;
   }
   else if((%tan >= 0.167356)&&(%tan < 0.185354))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 10;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 190;
      }
      return %angle;
   }
   else if((%tan >= 0.185354)&&(%tan < 0.203468))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 11;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 191;
      }
      return %angle;
   }
   else if((%tan >= 0.203468)&&(%tan < 0.221712))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 12;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 192;
      }
      return %angle;
   }
   else if((%tan >= 0.221712)&&(%tan < 0.240098))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 13;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 193;
      }
      return %angle;
   }
   else if((%tan >= 0.240098)&&(%tan < 0.258639))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 14;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 194;
      }
      return %angle;
   }
   else if((%tan >= 0.258639)&&(%tan < 0.277347))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 15;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 195;
      }
      return %angle;
   }
   else if((%tan >= 0.277347)&&(%tan < 0.296238))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 16;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 196;
      }
      return %angle;
   }
   else if((%tan >= 0.296238)&&(%tan < 0.315325))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 17;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 197;
      }
      return %angle;
   }
   else if((%tan >= 0.315325)&&(%tan < 0.334624))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 18;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 198;
      }
      return %angle;
   }
   else if((%tan >= 0.334624)&&(%tan < 0.354149))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 19;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 199;
      }
      return %angle;
   }
   else if((%tan >= 0.354149)&&(%tan < 0.373917))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 20;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 200;
      }
      return %angle;
   }
   else
   {
      getVector2(%deltaX, %deltaY);
   }
}

function getVector2(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan >= 0.373917)&&(%tan < 0.393945))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 21;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 201;
      }
      return %angle;
   }
   else if((%tan >= 0.393945)&&(%tan < 0.414251))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 22;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 202;
      }
      return %angle;
   }
   else if((%tan >= 0.414251)&&(%tan < 0.434852))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 23;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 203;
      }
      return %angle;
   }
   else if((%tan >= 0.434852)&&(%tan < 0.455768))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 24;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 204;
      }
      return %angle;
   }
   else if((%tan >= 0.455768)&&(%tan < 0.477020))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 25;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 205;
      }
      return %angle;
   }
   else if((%tan >= 0.477020)&&(%tan < 0.498629))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 26;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 206;
      }
      return %angle;
   }
   else if((%tan >= 0.498629)&&(%tan < 0.520617))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 27;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 207;
      }
      return %angle;
   }
   else if((%tan >= 0.520617)&&(%tan < 0.543009))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 28;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 208;
      }
      return %angle;
   }
   else if((%tan >= 0.543009)&&(%tan < 0.565830))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 29;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 209;
      }
      return %angle;
   }
   else if((%tan >= 0.565830)&&(%tan < 0.589105))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 30;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 210;
      }
      return %angle;
   }
   else if((%tan >= 0.589105)&&(%tan < 0.612865))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 31;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 211;
      }
      return %angle;
   }
   else if((%tan >= 0.612865)&&(%tan < 0.637138))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 32;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 212;
      }
      return %angle;
   }
   else if((%tan >= 0.637138)&&(%tan < 0.661958))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 33;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 213;
      }
      return %angle;
   }
   else if((%tan >= 0.661958)&&(%tan < 0.687358))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 34;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 214;
      }
      return %angle;
   }
   else if((%tan >= 0.687358)&&(%tan < 0.713375))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 35;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 215;
      }
      return %angle;
   }
   else if((%tan >= 0.713375)&&(%tan < 0.740048))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 36;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 216;
      }
      return %angle;
   }
   else if((%tan >= 0.740048)&&(%tan < 0.767420))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 37;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 217;
      }
      return %angle;
   }
   else if((%tan >= 0.767420)&&(%tan < 0.795535))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 38;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 218;
      }
      return %angle;
   }
   else if((%tan >= 0.795535)&&(%tan < 0.824442))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 39;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 219;
      }
      return %angle;
   }
   else if((%tan >= 0.824442)&&(%tan < 0.854193))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 40;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 220;
      }
      return %angle;
   }
   else
   {
      getVector3(%deltaX, %deltaY);
   }
}

function getVector3(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan >= 0.854193)&&(%tan < 0.884845))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 41;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 221;
      }
      return %angle;
   }
   else if((%tan >= 0.884845)&&(%tan < 0.916460))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 42;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 222;
      }
      return %angle;
   }
   else if((%tan >= 0.916460)&&(%tan < 0.949102))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 43;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 223;
      }
      return %angle;
   }
   else if((%tan >= 0.949102)&&(%tan < 0.982844))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 44;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 224;
      }
      return %angle;
   }
   else if((%tan >= 0.982844)&&(%tan < 1.017765))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 45;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 225;
      }
      return %angle;
   }
   else if((%tan >= 1.017765)&&(%tan < 1.053950))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 46;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 226;
      }
      return %angle;
   }
   else if((%tan >= 1.053950)&&(%tan < 1.091491))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {

         %angle = 47;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 227;
      }
      return %angle;
   }
   else if((%tan >= 1.091491)&&(%tan < 1.130490))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 48;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 228;
      }
      return %angle;
   }
   else if((%tan >= 1.130490)&&(%tan < 1.171061))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 49;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 229;
      }
      return %angle;
   }
   else if((%tan >= 1.171061)&&(%tan < 1.213325))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 50;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 230;
      }
      return %angle;
   }
   else if((%tan >= 1.213325)&&(%tan < 1.257419))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 51;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 231;
      }
      return %angle;
   }
   else if((%tan >= 1.257419)&&(%tan < 1.303493))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 52;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 232;
      }
      return %angle;
   }
   else if((%tan >= 1.303493)&&(%tan < 1.351713))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 53;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 233;
      }
      return %angle;
   }
   else if((%tan >= 1.351713)&&(%tan < 1.402265))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 54;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 234;
      }
      return %angle;
   }
   else if((%tan >= 1.402265)&&(%tan < 1.455354))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 55;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 235;
      }
      return %angle;
   }
   else if((%tan >= 1.455354)&&(%tan < 1.511213))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 56;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 236;
      }
      return %angle;
   }
   else if((%tan >= 1.511213)&&(%tan < 1.570100))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 57;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 237;
      }
      return %angle;
   }
   else if((%tan >= 1.570100)&&(%tan < 1.632307))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 58;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 238;
      }
      return %angle;
   }
   else if((%tan >= 1.632307)&&(%tan < 1.698165))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 59;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 239;
      }
      return %angle;
   }
   else if((%tan >= 1.698165)&&(%tan < 1.768049))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 60;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 240;
      }
      return %angle;
   }
   else
   {
      getVector4(%deltaX, %deltaY);
   }
}

function getVector4(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan >= 1.768049)&&(%tan < 1.842387))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 61;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 241;
      }
      return %angle;
   }
   else if((%tan >= 1.842387)&&(%tan < 1.921668))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 62;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 242;
      }
      return %angle;
   }
   else if((%tan >= 1.921668)&&(%tan < 2.006457))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 63;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 243;
      }
      return %angle;
   }
   else if((%tan >= 2.006457)&&(%tan < 2.097405))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 64;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 244;
      }
      return %angle;
   }
   else if((%tan >= 2.097405)&&(%tan < 2.195272))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 65;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 245;
      }
      return %angle;
   }
   else if((%tan >= 2.195272)&&(%tan < 2.300945))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 66;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 246;
      }
      return %angle;
   }
   else if((%tan >= 2.300945)&&(%tan < 2.415470))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 67;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 247;
      }
      return %angle;
   }
   else if((%tan >= 2.415470)&&(%tan < 2.540088))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 68;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 248;
      }
      return %angle;
   }
   else if((%tan >= 2.540088)&&(%tan < 2.676283))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 69;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 249;
      }
      return %angle;
   }
   else if((%tan >= 2.676283)&&(%tan < 2.825844))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 70;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 250;
      }
      return %angle;
   }
   else if((%tan >= 2.825844)&&(%tan < 2.990947))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 71;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 251;
      }
      return %angle;
   }
   else if((%tan >= 2.990947)&&(%tan < 3.174268))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 72;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 252;
      }
      return %angle;
   }
   else if((%tan >= 3.174268)&&(%tan < 3.379134))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 73;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 253;
      }
      return %angle;
   }
   else if((%tan >= 3.379134)&&(%tan < 3.609733))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 74;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 254;
      }
      return %angle;
   }
   else if((%tan >= 3.609733)&&(%tan < 3.871416))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 75;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 255;
      }
      return %angle;
   }
   else if((%tan >= 3.871416)&&(%tan < 4.171128))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 76;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 256;
      }
      return %angle;
   }
   else if((%tan >= 4.171128)&&(%tan < 4.518053))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 77;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 257;
      }
      return %angle;
   }
   else if((%tan >= 4.518053)&&(%tan < 4.924592))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 78;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 258;
      }
      return %angle;
   }
   else if((%tan >= 4.924592)&&(%tan < 5.407918))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 79;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 259;
      }
      return %angle;
   }
   else if((%tan >= 5.407918)&&(%tan < 5.992517))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 80;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 260;
      }
      return %angle;
   }
   else
   {
      getVector5(%deltaX, %deltaY);
   }
}

function getVector5(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan >= 5.992517)&&(%tan < 6.714561))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 81;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 261;
      }
      return %angle;
   }
   else if((%tan >= 6.714561)&&(%tan < 7.629858))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 82;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 262;
      }
      return %angle;
   }
   else if((%tan >= 7.629858)&&(%tan < 8.829355))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 83;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 263;
      }
      return %angle;
   }
   else if((%tan >= 8.829355)&&(%tan < 10.472208))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 84;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 264;
      }
      return %angle;
   }
   else if((%tan >= 10.472208)&&(%tan < 12.865359))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 85;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 265;
      }
      return %angle;
   }
   else if((%tan >= 12.865359)&&(%tan < 16.690901))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 86;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 266;
      }
      return %angle;
   }
   else if((%tan >= 16.690901)&&(%tan < 23.858695))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 87;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 267;
      }
      return %angle;
   }
   else if((%tan >= 23.858695)&&(%tan < 42.963107))
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 88;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 268;
      }
      return %angle;
   }
   else if(%tan >= 42.963107)
   {
      if((%deltaX > 0)&&(%deltaY > 0))
      {
         %angle = 89;
      }
      else if((%deltaX < 0)&&(%deltaY < 0))
      {
         %angle = 269;
      }
      return %angle;
   }
   else if(%deltaX == 0)
   {
      if(%deltaY > 0)
      {
         %angle = 90;
      }
      else if(%deltaY < 0)
      {
         %angle = 270;
      }
      return %angle;
   }
   else if(%tan < -42.963107)
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 91;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 271;
      }
      return %angle;
   }
   else if((%tan < -23.858695)&&(%tan >= -42.963107))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 92;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 272;
      }
      return %angle;
   }
   else if((%tan < -16.690901)&&(%tan >= -23.858695))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 93;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 273;
      }
      return %angle;
   }
   else if((%tan < -12.865359)&&(%tan >= -16.690901))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 94;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 274;
      }
      return %angle;
   }
   else if((%tan < -10.472208)&&(%tan >= -12.865359))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 95;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 275;
      }
      return %angle;
   }
   else if((%tan < -8.829355)&&(%tan >= -10.472208))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 96;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 276;
      }
      return %angle;
   }
   else if((%tan < -7.629858)&&(%tan >= -8.829355))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 97;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 277;
      }
      return %angle;
   }
   else if((%tan < -6.714561)&&(%tan >= -7.629858))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 98;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 278;
      }
      return %angle;
   }
   else if((%tan < -5.992517)&&(%tan >= -6.714561))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 99;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 279;
      }
      return %angle;
   }
   else if((%tan < -5.407918)&&(%tan >= -5.992517))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 100;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 280;
      }
      return %angle;
   }
   else
   {
      getVector6(%deltaX, %deltaY);
   }
}

function getVector6(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan < -4.924592)&&(%tan >= -5.407918))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 101;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 281;
      }
      return %angle;
   }
   else if((%tan < -4.518053)&&(%tan >= -4.924592))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 102;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 282;
      }
      return %angle;
   }
   else if((%tan < -4.171128)&&(%tan >= -4.518053))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 103;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 283;
      }
      return %angle;
   }
   else if((%tan < -3.871416)&&(%tan >= -4.171128))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 104;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 284;
      }
      return %angle;
   }
   else if((%tan < -3.609733)&&(%tan >= -3.871416))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 105;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 285;
      }
      return %angle;
   }
   else if((%tan < -3.379134)&&(%tan >= -3.609733))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 106;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 286;
      }
      return %angle;
   }
   else if((%tan < -3.174268)&&(%tan >= -3.379134))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 107;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 287;
      }
      return %angle;
   }
   else if((%tan < -2.990947)&&(%tan >= -3.174268))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 108;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 288;
      }
      return %angle;
   }
   else if((%tan < -2.825844)&&(%tan >= -2.990947))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 109;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 289;
      }
      return %angle;
   }
   else if((%tan < -2.676283)&&(%tan >= -2.825844))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 110;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 290;
      }
      return %angle;
   }
   else if((%tan < -2.540088)&&(%tan >= -2.676283))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 111;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 291;
      }
      return %angle;
   }
   else if((%tan < -2.415470)&&(%tan >= -2.540088))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 112;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 292;
      }
      return %angle;
   }
   else if((%tan < -2.300945)&&(%tan >= -2.415470))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 113;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 293;
      }
      return %angle;
   }
   else if((%tan < -2.195272)&&(%tan >= -2.300945))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 114;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 294;
      }
      return %angle;
   }
   else if((%tan < -2.097405)&&(%tan >= -2.195272))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 115;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 295;
      }
      return %angle;
   }
   else if((%tan < -2.006457)&&(%tan >= -2.097405))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 116;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 296;
      }
      return %angle;
   }
   else if((%tan < -1.921668)&&(%tan >= -2.006457))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 117;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 297;
      }
      return %angle;
   }
   else if((%tan < -1.842387)&&(%tan >= -1.921668))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 118;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 298;
      }
      return %angle;
   }
   else if((%tan < -1.768049)&&(%tan >= -1.842387))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 119;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 299;
      }
      return %angle;
   }
   else if((%tan < -1.698165)&&(%tan >= -1.768049))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 120;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 300;
      }
      return %angle;
   }
   else
   {
      getVector7(%deltaX, %deltaY);
   }
}

function getVector7(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan < -1.632307)&&(%tan >= -1.698165))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 121;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 301;
      }
      return %angle;
   }
   else if((%tan < -1.570100)&&(%tan >= -1.632307))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 122;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 302;
      }
      return %angle;
   }
   else if((%tan < -1.511213)&&(%tan >= -1.570100))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 123;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 303;
      }
      return %angle;
   }
   else if((%tan < -1.455354)&&(%tan >= -1.511213))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 124;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 304;
      }
      return %angle;
   }
   else if((%tan < -1.402265)&&(%tan >= -1.455354))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 125;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 305;
      }
      return %angle;
   }
   else if((%tan < -1.351713)&&(%tan >= -1.402265))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 126;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 306;
      }
      return %angle;
   }
   else if((%tan < -1.303493)&&(%tan >= -1.351713))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 127;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 307;
      }
      return %angle;
   }
   else if((%tan < -1.257419)&&(%tan >= -1.303493))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 128;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 308;
      }
      return %angle;
   }
   else if((%tan < -1.213325)&&(%tan >= -1.257419))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 129;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 309;
      }
      return %angle;
   }
   else if((%tan < -1.171061)&&(%tan >= -1.213325))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 130;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 310;
      }
      return %angle;
   }
   else if((%tan < -1.130490)&&(%tan >= -1.171061))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 131;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 311;
      }
      return %angle;
   }
   else if((%tan < -1.091491)&&(%tan >= -1.130490))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 132;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 312;
      }
      return %angle;
   }
   else if((%tan < -1.053950)&&(%tan >= -1.091491))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 133;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 313;
      }
      return %angle;
   }
   else if((%tan < -1.017765)&&(%tan >= -1.053950))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 134;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 314;
      }
      return %angle;
   }
   else if((%tan < -0.982844)&&(%tan >= -1.017765))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 135;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 315;
      }
      return %angle;
   }
   else if((%tan < -0.949102)&&(%tan >= -0.982844))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 136;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 316;
      }
      return %angle;
   }
   else if((%tan < -0.916460)&&(%tan >= -0.949102))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 137;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 317;
      }
      return %angle;
   }
   else if((%tan < -0.884845)&&(%tan >= -0.916460))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 138;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 318;
      }
      return %angle;
   }
   else if((%tan < -0.854193)&&(%tan >= -0.884845))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 139;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 319;
      }
      return %angle;
   }
   else if((%tan < -0.824442)&&(%tan >= -0.854193))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 140;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 320;
      }
      return %angle;
   }
   else
   {
      getVector8(%deltaX, %deltaY);
   }
}

function getVector8(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan < -0.795535)&&(%tan >= -0.824442))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 141;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 321;
      }
      return %angle;
   }
   else if((%tan < -0.767420)&&(%tan >= -0.795535))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 142;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 322;
      }
      return %angle;
   }
   else if((%tan < -0.740048)&&(%tan >= -0.767420))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 143;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 323;
      }
      return %angle;
   }
   else if((%tan < -0.713375)&&(%tan >= -0.740048))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 144;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 324;
      }
      return %angle;
   }
   else if((%tan < -0.687358)&&(%tan >= -0.713375))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 145;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 325;
      }
      return %angle;
   }
   else if((%tan < -0.661958)&&(%tan >= -0.687358))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 146;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 326;
      }
      return %angle;
   }
   else if((%tan < -0.637138)&&(%tan >= -0.661958))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 147;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 327;
      }
      return %angle;
   }
   else if((%tan < -0.612865)&&(%tan >= -0.637138))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 148;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 328;
      }
      return %angle;
   }
   else if((%tan < -0.589105)&&(%tan >= -0.612865))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 149;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 329;
      }
      return %angle;
   }
   else if((%tan < -0.565830)&&(%tan >= -0.589105))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 150;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 330;
      }
      return %angle;
   }
   else if((%tan < -0.543009)&&(%tan >= -0.565830))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 151;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 331;
      }
      return %angle;
   }
   else if((%tan < -0.520617)&&(%tan >= -0.543009))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 152;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 332;
      }
      return %angle;
   }
   else if((%tan < -0.498629)&&(%tan >= -0.520617))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 153;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 333;
      }
      return %angle;
   }
   else if((%tan < -0.477020)&&(%tan >= -0.498629))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 154;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 334;
      }
      return %angle;
   }
   else if((%tan < -0.455768)&&(%tan >= -0.477020))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 155;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 335;
      }
      return %angle;
   }
   else if((%tan < -0.434852)&&(%tan >= -0.455768))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 156;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 336;
      }
      return %angle;
   }
   else if((%tan < -0.414251)&&(%tan >= -0.434852))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 157;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 337;
      }
      return %angle;
   }
   else if((%tan < -0.393945)&&(%tan >= -0.414251))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 158;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 338;
      }
      return %angle;
   }
   else if((%tan < -0.373917)&&(%tan >= -0.393945))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 159;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 339;
      }
      return %angle;
   }
   else if((%tan < -0.354149)&&(%tan >= -0.373917))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 160;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 340;
      }
      return %angle;
   }
   else
   {
      getVector9(%deltaX, %deltaY);
   }
}

function getVector9(%deltaX, %deltaY)
{
   %tan = (%deltaY / %deltaX);
   if((%tan < -0.334624)&&(%tan >= -0.354149))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 161;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 341;
      }
      return %angle;
   }
   else if((%tan < -0.315325)&&(%tan >= -0.334624))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 162;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 342;
      }
      return %angle;
   }
   else if((%tan < -0.296238)&&(%tan >= -0.315325))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 163;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 343;
      }
      return %angle;
   }
   else if((%tan < -0.277347)&&(%tan >= -0.296238))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 164;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 344;
      }
      return %angle;
   }
   else if((%tan < -0.258639)&&(%tan >= -0.277347))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 165;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 345;
      }
      return %angle;
   }
   else if((%tan < -0.240098)&&(%tan >= -0.258639))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 166;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 346;
      }
      return %angle;
   }
   else if((%tan < -0.221712)&&(%tan >= -0.240098))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 167;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 347;
      }
      return %angle;
   }
   else if((%tan < -0.203468)&&(%tan >= -0.221712))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 168;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 348;
      }
      return %angle;
   }
   else if((%tan < -0.185354)&&(%tan >= -0.203468))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 169;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 349;
      }
      return %angle;
   }
   else if((%tan < -0.167356)&&(%tan >= -0.185354))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 170;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 350;
      }
      return %angle;
   }
   else if((%tan < -0.149463)&&(%tan >= -0.167356))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 171;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 351;
      }
      return %angle;
   }
   else if((%tan < -0.131663)&&(%tan >= -0.149463))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 172;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 352;
      }
      return %angle;
   }
   else if((%tan < -0.113944)&&(%tan >= -0.131663))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 173;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 353;
      }
      return %angle;
   }
   else if((%tan < -0.096296)&&(%tan >= -0.113944))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 174;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 354;
      }
      return %angle;
   }
   else if((%tan < -0.078708)&&(%tan >= -0.096296))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 175;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 355;
      }
      return %angle;
   }
   else if((%tan < -0.061167)&&(%tan >= -0.078708))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 176;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 356;
      }
      return %angle;
   }
   else if((%tan < -0.043664)&&(%tan >= -0.061167))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 177;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 357;
      }
      return %angle;
   }
   else if((%tan < -0.026188)&&(%tan >= -0.043664))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 178;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 358;
      }
      return %angle;
   }
   else if((%tan < -0.008728)&&(%tan >= -0.026188))
   {
      if((%deltaX < 0)&&(%deltaY > 0))
      {
         %angle = 179;
      }
      else if((%deltaX > 0)&&(%deltaY < 0))
      {
         %angle = 359;
      }
      return %angle;
   }
}